@@ -30,15 +30,14 @@ class TextPosition:
 
     # :: CONSTRUCTOR :: #
 
-    def __init__(self, pos: int, col: int, ln: int) -> None:
+    def __init__(self, pos: int=0, col: int=0, ln: int=0) -> None:
         """TextPosition object instance initializer.
 
         Parameters
         ----------
         pos : int, optional
             Absolute position in a text file. Note that multi-byte characters are counted
-            as one position. Therefore this value should only be used by Textstream
-            objects.
+            as one position.
         col : int, optional
             Column at a position in a text file. Counting starts from 0.
         ln : int, optional
