@@ -272,7 +272,7 @@ class TestCppTokenization (ut.TestCase):
         while(1):
 
             try: token = lexer.get_next_token()
-            except lex2.excs.EOD:
+            except lex2.excs.EOF:
                 break
 
             # info = [
