@@ -85,7 +85,7 @@ class Test_MultispanComment (ut.TestCase):
         while(1):
 
             try: token = lexer.get_next_token()
-            except lex2.excs.EOD:
+            except lex2.excs.EOF:
                 break
 
             if (token.is_rule(_rules.word)):
